@@ -98,6 +98,9 @@ Pixmap		alarmoff_pixmap;
  */
 PostItNote	*notes = NULL;
 
+static int raisestatus = 1;
+static int showstatus = 1;
+
 extern void ErrPopDown();
 extern void ErrPopUp();
 extern void TimerPopDown();
@@ -137,6 +140,7 @@ static void 		UnSetTimerNote();
 static void 		MakeAlarmPopup();
 static void 		AlarmPopDown();
 static void 		EmailNoteCB();
+static int		StringToNoteSize();
 
 /*
  * CreateNewNote - create a new note of the specified size.
@@ -456,6 +460,7 @@ RaiseAllNotes()
 	Boolean found;
 
 	found = False;
+	raisestatus = 1;
 	for (pn = notes; pn != NULL; pn = pn->pn_next)
 	{
 		XRaiseWindow(display, XtWindow(pn->pn_shellwidget));
@@ -466,6 +471,31 @@ RaiseAllNotes()
 		ErrPopUp("There are no notes to raise.");
 }
 
+/*
+ * HideAllNotes - hide all the notes
+ */
+void
+HideAllNotes()
+{
+	register PostItNote *pn;
+	Boolean found;
+
+	found = False;
+	showstatus = 0;
+	for (pn = notes; pn != NULL; pn = pn->pn_next)
+	{
+		if (pn->pn_hidden == False)
+		{
+			XtPopdown ( pn->pn_shellwidget );
+			pn->pn_hidden = True;
+			found = True;
+		}
+	}
+
+	if ( !found )
+		ErrPopUp("There are no notes to hide.");
+}
+
 /*
  * UnHideAllNotes - unhide all hidden notes
  */
@@ -476,6 +506,7 @@ UnHideAllNotes()
 	Boolean	found;
 
 	found = False;
+	showstatus = 1;
 	for (pn = notes; pn != NULL; pn = pn->pn_next)
 		if ( pn->pn_hidden )
 		{
@@ -498,6 +529,7 @@ LowerAllNotes()
 	Boolean found;
 
 	found = False;
+	raisestatus = 0;
 	for (pn = notes; pn != NULL; pn = pn->pn_next)
 	{
 		XLowerWindow(display, XtWindow(pn->pn_shellwidget));
@@ -508,6 +540,25 @@ LowerAllNotes()
 		ErrPopUp("There are no notes to lower.");
 }
 
+/*
+ * ToggleRaise - toggle raise status
+ */
+void
+ToggleRaise() {
+	if(!showstatus) {
+		UnHideAllNotes(); RaiseAllNotes();
+	} else
+		raisestatus ? LowerAllNotes() : RaiseAllNotes();
+}
+
+/*
+ * ToggleShow - toggle show status
+ */
+void
+ToggleShow() {
+	showstatus ? HideAllNotes() : UnHideAllNotes();
+}
+
 /*
  * SaveAllNotes - save all the notes.
  */
@@ -530,6 +581,49 @@ int	showmsg;
 			ErrPopUp("There are no notes to save.");
 }
 
+/*
+ * MakeNewNote - called from the "tearoff" action.
+ */
+void
+MakeNewNote(w, client_data, call_data)
+XtPointer client_data, call_data;
+Widget w;
+{
+	int notesize;
+
+	if (call_data)
+		notesize = StringToNoteSize((char *) call_data);
+	else
+		notesize = PostItNote_1p5x2;    /* arbitrary default */
+
+	CreateNewNote(notesize);
+}
+
+/*
+ * StringToNoteSize - convert strings to note sizes.
+ */
+static int
+StringToNoteSize(s)
+char *s;
+{
+	if (strcmp(s, "1.5x2") == 0)
+		return(PostItNote_1p5x2);
+	else if (strcmp(s, "2x3") == 0)
+		return(PostItNote_2x3);
+	else if (strcmp(s, "3x3") == 0)
+		return(PostItNote_3x3);
+	else if (strcmp(s, "3x4") == 0)
+		return(PostItNote_3x4);
+	else if (strcmp(s, "3x5") == 0)
+		return(PostItNote_3x5);
+	else if (strcmp(s, "4x6") == 0)
+		return(PostItNote_4x6);
+	else
+		fprintf(stderr, "xpostit: bad note size: \"%s\".\n", s);
+
+	return(PostItNote_1p5x2);
+}
+
 /*
  * CascadeNotes - cascade the notes on any anchor notes.
  * This isn't the best, but it distributes the notes among the notes
